| Title: | A template and tools for data analysis R Markdown documents |
|---|---|
| Description: | A template for R Markdown that I like to use for data analysis. Also, a utility for creating a metadata template from a dataframe. |
| Authors: | Eric Scott [aut, cre] (ORCID: <https://orcid.org/0000-0002-7430-7879>) |
| Maintainer: | Eric Scott <[email protected]> |
| License: | CC0 |
| Version: | 0.0.0.9003 |
| Built: | 2026-06-04 07:14:14 UTC |
| Source: | https://github.com/Aariq/mynotebooks |
Insert data dictionary
df_dict(x = NULL)df_dict(x = NULL)
x |
a data frame |
Inserts a data dictionary template as a markdown list at the cursor
## Not run: df_dict(warpbreaks) ## End(Not run)## Not run: df_dict(warpbreaks) ## End(Not run)